RoomReadReceipts

Struct RoomReadReceipts 

pub struct RoomReadReceipts {
    pub num_unread: u64,
    pub num_notifications: u64,
    pub num_mentions: u64,
    pub latest_active: Option<LatestReadReceipt>,
    pub pending: RingBuffer<OwnedEventId>,
}
Public data about read receipts collected during processing of that room.

Remember that each time a field of RoomReadReceipts is updated in compute_unread_counts, this function must return true!

Fields

num_unread: u64

Does the room have unread messages?

num_notifications: u64

Does the room have unread events that should notify?

num_mentions: u64

Does the room have messages causing highlights for the users? (aka mentions)

latest_active: Option<LatestReadReceipt>

The latest read receipt (main-threaded or unthreaded) known for the room.

pending: RingBuffer<OwnedEventId>

Read receipts that haven’t been matched to their event.

This might mean that the read receipt is in the past further than we recall (i.e. before the first event we’ve ever cached), or in the future (i.e. the event is lagging behind because of federation).

Note: this contains event ids of the event targets of the receipts, not the event ids of the receipt events themselves.